Learn R Programming

mgsa (version 1.14.2)

MgsaMcmcResults: Instances of this class are used to hold the additional information that was provided by running (possibly multiple times) an MCMC algorithm.

Description

Instances of this class are used to hold the additional information that was provided by running (possibly multiple times) an MCMC algorithm.

Arguments

Slots

  • stepshow many steps per MCMC run
  • restartshow many MCMC runs
  • alphaMcmcPostposterior estimates for each MCMC run of the parameter alpha
  • betaMcmcPostposterior estimates for each MCMC run of the parameter beta
  • pMcmcPostposterior estimates for each MCMC run of the parameter p
  • setsMcmcPostposterior estimates for each MCMC run of the sets marginal posterior probabilities The columns of the matrices alphaMcmcPost, betaMcmcPost, pMcmcPost and setsMcmcPost stores the posterior estimates for each individual MCMC run. The row order matches the one of the slot alphaPost, betaPost, pPots, and setsResults respectively. Accessor methods exist for each slot.

See Also

mgsa