MgsaResults: Results of an MGSA analysis
Description
The results of an MGSA analysis.
Slots
- populationSizeThe number of items in the
population.
- studySetSizeInPopulationThe number of items both
in the study set and in the population.
- alphaPostwith columns
value,
estimate and std.error.
- betaPostwith columns
value,
estimate and std.error.
- pPostwith columns
value, estimate
and std.error.
- setsResultswith columns
inPopulation,
inStudySet, estimate and std.error. The columns of the slots alphaPost,
betaPost, and pPost contains a realization
value, its posterior estimate and standard error for the
parameters alpha, beta and p respectively. The columns of the slot setsResults contains the
number of items of the set in the population, the number
of items of the set in the study set, the estimate of its
marginal posterior probability and its standard error.
The rownames are the names of the sets if
available. Because an MgsaResults is the outcome of an MGSA
analysis (see mgsa), accessors but no
replacement methods exist for each slot.