This class describes sets, items and their annotations.
Arguments
Slots
setsA list whose elements are vector of item
indices.
itemName2ItemIndexThe mapping of item names to
index.
numberOfItemsHow many items?
setAnnotationsAnnotations of the sets. The
rownames are set names.
itemAnnotationsAnnotations of the items. The
rownames are item names.
Details
Internally, the method mgsa indexes all
elements of the sets before fitting the model. In case
mgsa must be run on several observations
with the same gene sets, computations can be speeded up
by performing this indexing once for all. This can be
achieved by building a MgsaSets. In
order to ensure consistency of the indexing, no replace
method for any slot is provided. Accessors are available.
The data frames setAnnotations and
itemAnnotations allow to store annotations. No
constraint is imposed on the number and names of their
columns.